#!/opt/concourse/worker/volumes/live/07c91fcd-d991-47ef-60eb-58d529b2595d/volume/anaconda-navigator_1632168915852/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placeh/Anaconda-Navigator.app/Contents/MacOS/python
from subprocess import call

call(["/opt/concourse/worker/volumes/live/07c91fcd-d991-47ef-60eb-58d529b2595d/volume/anaconda-navigator_1632168915852/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placeh/bin/anaconda-navigator"])
